==> nextcloud-17.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/accessibility/l10n/da.js <==
OC.L10N.register(
    "accessibility",
    {
    "Dark theme" : "Mørk tema",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness. It is still under development, so please report any issues you may find." : "Et mørk tema, venligere for øjnene ved at dæmpe lysstyrken. Det er stadig under udvikling så indberet venligst alle problemer du måtte finde.",
    "High contrast mode" : "Højkontrasttilstand",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "En højkontrasttilstand letter navigationen. Presentation af lavere kvalitet, men tydeligere.",
    "Dyslexia font" : "Skrifftype for ordblinde",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic er en gratis skrifttype designet til at undgå læsefejl pga. ordblindhed",
    "Accessibility" : "Handicapvenlig",
    "Accessibility options for nextcloud" : "Handicapvenlige indstillinger for nextcloud",
    "Provides multiple accessibilities options to ease your use of Nextcloud" : "Tilbyder flere handicapvenlige indstillinger til at lette brugen af Nextcloud",
    "Web Content Accessibility Guidelines" : "Handicapvenlige retningslinjer for Web sider",
    "our issue tracker" : "vores problem følger",
    "our design team" : "vores design team",
    "Enable" : "Aktiver",
    "High contrast theme" : "Højkontrasttema",
    "A high contrast theme to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Et højkontrasttema letter navigationen. Presentation af lavere kvalitet, men tydeligere.",
    "Dark theme (beta)" : "Mørkt tema (beta)",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia. The typeface was created by Abelardo Gonzalez, who released it through an open-source license." : "OpenDyslexic er en gratis skrifttype/font designet til at undgå typiske læsefejl pga. ordblindhed. Skrifttypen er skabt af Abelardo Gonzalez, som har udgivet den med en open-source licens.",
    "Provides multiple accessibilities options to ease your use of nextcloud" : "Tilbyder flere handicapvenlige indstillinger til at lette brugen af Nextcloud",
    "Themes" : "Temaer",
    "Fonts" : "Fonte",
    "enabled" : "aktiveret"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-17.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/accessibility/l10n/da.js <==
OC.L10N.register(
    "accessibility",
    {
    "Dark theme" : "Mørk tema",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness. It is still under development, so please report any issues you may find." : "Et mørk tema, venligere for øjnene ved at dæmpe lysstyrken. Det er stadig under udvikling så indberet venligst alle problemer du måtte finde.",
    "High contrast mode" : "Højkontrasttilstand",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "En højkontrasttilstand letter navigationen. Presentation af lavere kvalitet, men tydeligere.",
    "Dyslexia font" : "Skrifftype for ordblinde",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic er en gratis skrifttype designet til at undgå læsefejl pga. ordblindhed",
    "Accessibility" : "Handicapvenlig",
    "Accessibility options for nextcloud" : "Handicapvenlige indstillinger for nextcloud",
    "Provides multiple accessibilities options to ease your use of Nextcloud" : "Tilbyder flere handicapvenlige indstillinger til at lette brugen af Nextcloud",
    "Web Content Accessibility Guidelines" : "Handicapvenlige retningslinjer for Web sider",
    "our issue tracker" : "vores problem følger",
    "our design team" : "vores designteam",
    "Enable" : "Aktivér",
    "High contrast theme" : "Højkontrasttema",
    "A high contrast theme to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Et højkontrasttema letter navigationen. Presentation af lavere kvalitet, men tydeligere.",
    "Dark theme (beta)" : "Mørkt tema (beta)",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia. The typeface was created by Abelardo Gonzalez, who released it through an open-source license." : "OpenDyslexic er en gratis skrifttype/font designet til at undgå typiske læsefejl pga. ordblindhed. Skrifttypen er skabt af Abelardo Gonzalez, som har udgivet den med en open-source licens.",
    "Provides multiple accessibilities options to ease your use of nextcloud" : "Tilbyder flere handicapvenlige indstillinger til at lette brugen af Nextcloud",
    "Themes" : "Temaer",
    "Fonts" : "Fonte",
    "enabled" : "aktiveret"
},
"nplurals=2; plural=(n != 1);");
